package com.classroom.assignment.controller;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.mvc.support.RedirectAttributes;
import com.classroom.assignment.entity.Todo;
import com.classroom.assignment.model.request.TodoForm;
import com.classroom.assignment.service.TodoService;

@Controller
@RequestMapping("/todo")
public class TodoController {

  private final TodoService todoService;

  @Autowired
  public TodoController(TodoService todoService) {
    this.todoService = todoService;
  }

  @GetMapping
  public String index(Model model) {
    List<Todo> list = todoService.selectAll();
    model.addAttribute("todoForm", new TodoForm());
    model.addAttribute("todoList", list);
    return "todo/index";
  }

  @PostMapping("/insert")
  public String insert(@Validated @ModelAttribute("todoForm") TodoForm todo,
      BindingResult result, Model model, RedirectAttributes redirectAttributes) {
    if (result.hasErrors()) {
      List<Todo> list = todoService.selectAll();
      model.addAttribute("todoList", list);
      return "todo/index";
    }
    todoService.insertTodo(todo.getTodo());

    return "redirect:/todo";
  }

  @GetMapping("/update/{id}/{checked}")
  public String update(@PathVariable("id") int id, @PathVariable("checked") boolean checked,
      Model model) {
    todoService.updateTodo(id, !checked);

    return "redirect:/todo";
  }

  @GetMapping("/delete")
  public String delete(@RequestParam("id") int id, Model model) {
    todoService.delete(id);

    return "redirect:/todo";
  }
}
